#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-check
version:              0.5.0.5
visibility:           public
id:                   ghc-check-0.5.0.5-CCSgnX4lIw84ICDsHqKQgD
key:                  ghc-check-0.5.0.5-CCSgnX4lIw84ICDsHqKQgD
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  5d15e298b594d971bbd61b91dec024d0
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-8.10.5/site-local/ghc-check-0.5.0.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/ghc-check-0.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/ghc-check-0.5.0.5
hs-libraries:         HSghc-check-0.5.0.5-CCSgnX4lIw84ICDsHqKQgD
depends:
    base-4.14.2.0 containers-0.6.4.1 directory-1.3.6.0 filepath-1.4.2.1
    ghc-8.10.5 ghc-paths-0.1.0.12-2xWgOnBVsu4JfFnY8cTnGw
    process-1.6.9.0 safe-exceptions-0.1.7.1-5k5YUvh9EUEA8260dxkQvv
    template-haskell-2.16.0.0 th-compat-0.1.2-BdbgSy57X82DD1FMq9Paem
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

